pub struct Input {
pub eventsSinceNumber: Option<FHIRString>,
pub eventsUntilNumber: Option<FHIRString>,
pub eventsSinceInstant: Option<FHIRInstant>,
pub eventsUntilInstant: Option<FHIRInstant>,
}Fields
eventsSinceNumber: Option<FHIRString>The starting event number, inclusive of this event (lower bound).
eventsUntilNumber: Option<FHIRString>The ending event number, inclusive of this event (upper bound).
eventsSinceInstant: Option<FHIRInstant>The starting event date/time, inclusive of this instant (lower bound).
eventsUntilInstant: Option<FHIRInstant>The ending event date/time, inclusive of this instant (upper bound).